from setuptools import setup, find_packages

setup(name='parsix_gazinform',
      version='1.1',
      description='A module that implements a test task for the Gazinformservice company',
      long_description='It helps to break down a string of log files into readable information.',
      author='Aleksandr Zakora',
      author_email='zakorro@gmail.com',
      packages=['parsix_gazinform'],
      )